Struct amazon_sp_aplus_content::models::standard_tech_specs_module::StandardTechSpecsModule
source · [−]pub struct StandardTechSpecsModule {
pub headline: Option<Box<TextComponent>>,
pub specification_list: Vec<StandardTextPairBlock>,
pub table_count: Option<i32>,
}Expand description
StandardTechSpecsModule : The standard table of technical feature names and definitions.
Fields
headline: Option<Box<TextComponent>>specification_list: Vec<StandardTextPairBlock>The specification list.
table_count: Option<i32>The number of tables to present. Features are evenly divided between the tables.
Implementations
sourceimpl StandardTechSpecsModule
impl StandardTechSpecsModule
sourcepub fn new(
specification_list: Vec<StandardTextPairBlock>
) -> StandardTechSpecsModule
pub fn new(
specification_list: Vec<StandardTextPairBlock>
) -> StandardTechSpecsModule
The standard table of technical feature names and definitions.